#ifndef NT2_INCLUDE_FUNCTIONS_IS_NOT_GREATER_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IS_NOT_GREATER_HPP_INCLUDED

#include <nt2/predicates/include/functions/is_not_greater.hpp>

#endif
